@@ -24,7 +24,7 @@ setMethod(
   signature = "ANY",
   definition = function(object) {
     NULL
-})
+  })
 
 ################################################################################
 #' Create a custom cache message by class
@@ -62,11 +62,11 @@ setMethod(
       messageCache(.loadedCacheMsg(.loadedMemoisedResultMsg, functionName), verbose = verbose)
     } else if (!is.na(fromMemoise)) {
       messageCache(.loadedCacheMsg(.loadedCacheResultMsg, functionName),
-                           "adding to memoised copy...", sep = "", verbose = verbose)
+                   "adding to memoised copy...", sep = "", verbose = verbose)
     } else {
       messageCache(.loadedCacheMsg(.loadedCacheResultMsg, functionName), verbose = verbose)
     }
-})
+  })
 
 ################################################################################
 #' Add tags to object
@@ -99,7 +99,7 @@ setMethod(
   signature = "ANY",
   definition = function(object, outputObjects, FUN, preDigestByClass) { # nolint
     object
-})
+  })
 
 ################################################################################
 #' Any miscellaneous things to do before \code{.robustDigest} and after \code{FUN} call
@@ -129,7 +129,7 @@ setMethod(
   signature = "ANY",
   definition = function(object) { # nolint
     NULL
-})
+  })
 
 ################################################################################
 #' Check for cache repository info in ...
@@ -168,7 +168,7 @@ setMethod(
         #  If no, then user is aware and doesn't need a message
         if (any(identical(normPath(tmpDir), normPath(getOption("reproducible.cachePath"))))) {
           messageCache("No cacheRepo supplied and getOption('reproducible.cachePath') is inside a temporary directory;\n",
-                  "  this will not persist across R sessions.", verbose = verbose)
+                       "  this will not persist across R sessions.", verbose = verbose)
         }
         getOption("reproducible.cachePath", tmpDir)
       } else {
@@ -177,7 +177,7 @@ setMethod(
       }
       checkPath(path = cacheRepo, create = create)
     })
-})
+  })
 
 ################################################################################
 #' Make any modifications to object recovered from cacheRepo
@@ -243,7 +243,7 @@ setMethod(
       }
     }
     object
-})
+  })
 
 #' @export
 #' @rdname prepareOutput
@@ -258,7 +258,7 @@ setMethod(
       }
     }
     object
-})
+  })
 
 ################################################################################
 #' Add an attribute to an object indicating which named elements change
@@ -291,7 +291,7 @@ setMethod(
   signature = "ANY",
   definition = function(object, preDigest, origArguments, ...) {
     object
-})
+  })
 
 #' A set of helpers for Cache
 #'
@@ -313,6 +313,7 @@ setMethod(
 #' @rdname cache-helpers
 getFunctionName <- function(FUN, originalDots, ..., overrideCall, isPipe) { # nolint
   callIndex <- numeric()
+  scalls <- sys.calls()
   if (isS4(FUN)) {
     # Have to extract the correct dispatched method
     firstElems <- strsplit(showMethods(FUN, inherited = TRUE, printTo = FALSE), split = ", ")
@@ -363,7 +364,6 @@ getFunctionName <- function(FUN, originalDots, ..., overrideCall, isPipe) { # no
     functionName <- FUN@generic
     FUN <- methodUsed@.Data  # nolint
   } else {
-    scalls <- sys.calls()
     if (!missing(overrideCall)) {
       callIndices <- .grepSysCalls(scalls, pattern = paste0("^", overrideCall))
       functionCall <- scalls[callIndices]
@@ -442,7 +442,10 @@ getFunctionName <- function(FUN, originalDots, ..., overrideCall, isPipe) { # no
   if (isTRUE(grepl(functionName, pattern = "\\(")))
     functionName <- NA_character_
 
-  return(list(functionName = functionName, .FUN = .FUN))#, callIndex = callIndex))
+  nestLevel <- length(grep(lapply(scalls, function(x) x[1:2]),
+                           pattern = "standardGeneric.+Cache"))
+
+  return(list(functionName = functionName, .FUN = .FUN, nestLevel = nestLevel - 1))#, callIndex = callIndex))
 }
 
 #' @exportClass Path
@@ -519,9 +522,9 @@ setAs(from = "character", to = "Path", function(from) {
 
 # Old one
 .prepareFileBackedRaster2 <- function(obj, repoDir = NULL, overwrite = FALSE,
-                                     drv = getOption("reproducible.drv", RSQLite::SQLite()),
-                                     conn = getOption("reproducible.conn", NULL),
-                                     ...) {
+                                      drv = getOption("reproducible.drv", RSQLite::SQLite()),
+                                      conn = getOption("reproducible.conn", NULL),
+                                      ...) {
   isRasterLayer <- TRUE
   isBrick <- is(obj, "RasterBrick")
   isStack <- is(obj, "RasterStack")
@@ -838,10 +841,10 @@ copySingleFile <- function(from = NULL, to = NULL, useRobocopy = TRUE,
         if (!dir.exists(to)) toDir <- dirname(to) # extract just the directory part
         rsyncBin <- tryCatch(Sys.which("rsync"), warning = function(w) NA_character_)
         opts <- if (silent) " -a " else " -avP "
-        # rsync command can't handle spaces in dirnames -- must protect them
+        # rsync command can't handle spaces file/dir names -- must protect them
         toDir <- gsub("\ ", "\\ ", toDir, fixed = TRUE)
         rsync <- paste0(rsyncBin, " ", opts, " --delete "[delDestination],
-                        normalizePath(from, mustWork = TRUE), " ",
+                        "'", normalizePath(from, mustWork = TRUE), "' ",
                         normalizePath(toDir, mustWork = FALSE), "/")
 
         useFileCopy <- tryCatch(system(rsync, intern = TRUE), error = function(x) TRUE)
@@ -1235,14 +1238,104 @@ dealWithRasters <- function(obj, cachePath, drv, conn) {
   paste0("     ", root," ", functionName, " call, ")
 }
 
+
+
+
+
+
+
+#' A helper function to change the filename slot of \code{Raster*} objects
+#'
+#' This is intended for internal use, though it is exported because other packages
+#' use this. This function exists because when copying file-backed rasters, the
+#' usual mechanism of \code{writeRaster} can be very slow. This function allows
+#' for a user to optionally create a hard link to the old file, give it a new
+#' name, then update the filename slot(s) in the \code{Raster*} class object. This
+#' can be 100s of times faster for large rasters.
+#'
+#' @export
+#' @keywords internal
+#' @param obj An object. This function only has useful methods for \code{Raster*},
+#'   with all other classes being simply a pass-through
+#' @param curFilenames An optional character vector of filenames currently existing
+#'   and that are pointed to in the obj. If omitted, will take from the \code{obj}
+#'   using \code{Filenames(obj)}
+#' @param newFilenames An optional character vector of filenames to use instead of
+#'   the curFilenames. This can also be a single directory, in which case the
+#'   renaming will be given:
+#'   \code{file.path(newFilenames, basename(Filenames(obj, allowMultiple = FALSE)))}
+#' @rdname updateFilenameSlots
 updateFilenameSlots <- function(obj, curFilenames, newFilenames, isStack = NULL) {
+  UseMethod("updateFilenameSlots")
+}
+
+#' @rdname updateFilenameSlots
+#' @export
+#' @keywords internal
+updateFilenameSlots.default <- function(obj, ...)  {
+  obj
+}
+
+#' @rdname updateFilenameSlots
+#' @export
+#' @keywords internal
+updateFilenameSlots.list <- function(obj, ...)  {
+
+  areRasters <- vapply(obj, is, "RasterLayer", FUN.VALUE = logical(1))
+  if (all(areRasters)) {
+    # a separate option for list of RasterLayers because curFilename will be
+    #   as long as all the filenames because there is a method for lists;
+    #   passing this to updateFilaneSlots will fail if it is one RasterLayer
+    #   at a time
+    out <- updateFilenameSlots(raster::stack(obj), ...)
+    out <- raster::unstack(out)
+  } else {
+    out <- lapply(obj, function(o) {
+      updateFilenameSlots(o, ...)
+    })
+  }
+  out
+
+}
+
+#' @rdname updateFilenameSlots
+#' @export
+#' @keywords internal
+updateFilenameSlots.environment <- function(obj, ...)  {
+  if (is.null(names(obj))) {
+    names(obj) <- as.character(seq(obj))
+  }
+  lapply(obj, function(o) {
+    updateFilenameSlots(as.list(o), ...)
+  })
+}
+
+
+#' @rdname updateFilenameSlots
+#' @export
+#' @keywords internal
+updateFilenameSlots.Raster <- function(obj, curFilenames, newFilenames, isStack = NULL) {
   if (isTRUE(getOption("reproducible.useNewDigestAlgorithm") < 2)) {
     return(updateFilenameSlots2(obj, curFilenames, newFilenames, isStack))
   }
+  if (missing(curFilenames)) {
+    curFilenames <- Filenames(obj, allowMultiple = FALSE)
+  }
+
+  if (missing(newFilenames)) stop("newFilenames can't be missing: either new filenames or a single directory")
+  # if newFilenames is a directory
+  areDirs <- dir.exists(newFilenames)
+  if (any(areDirs) && length(newFilenames) == 1) {
+    newFilenames <- file.path(newFilenames, basename(curFilenames))
+  }
 
   if (length(curFilenames) > 1) {
     for (i in seq_along(curFilenames)) {
-      slot(slot(slot(obj, "layers")[[i]], "file"), "name") <- newFilenames[i]
+      if (is.list(obj)) {
+        slot(slot(obj[[i]], "file"), "name") <- newFilenames[i]
+      } else {
+        slot(slot(slot(obj, "layers")[[i]], "file"), "name") <- newFilenames[i]
+      }
     }
   } else {
     if (is.null(isStack)) isStack <- is(obj, "RasterStack")
@@ -1259,7 +1352,7 @@ updateFilenameSlots <- function(obj, curFilenames, newFilenames, isStack = NULL)
       }
       for (i in seq_len(nlayers(obj))) {
         whFilename <- unique(match(withoutFinalNumeric(basename(newFilenames)),
-                            withoutFinalNumeric(basename(curFilenames))))
+                                   withoutFinalNumeric(basename(curFilenames))))
         isNAwhFn <- is.na(whFilename)
         if (any(isNAwhFn))
           whFilename <- i
@@ -1347,7 +1440,7 @@ updateFilenameSlots2 <- function(obj, curFilenames, newFilenames, isStack = NULL
                                      ...) {
   if (isTRUE(getOption("reproducible.useNewDigestAlgorithm") < 2)) {
     return(.prepareFileBackedRaster2(obj, repoDir = repoDir, overwrite = overwrite,
-                              drv = drv, conn = conn, ...))
+                                     drv = drv, conn = conn, ...))
   }
   fnsAll <- Filenames(obj)
   fnsShort <- Filenames(obj, FALSE)
@@ -1410,7 +1503,7 @@ updateFilenameSlots2 <- function(obj, curFilenames, newFilenames, isStack = NULL
     saveFilenamePreNumeric <- saveFilename
     exist <- file.exists(saveFilename)
     if (any(exist)) {
-      saveFilename[exist] <- nextNumericName(saveFilename[exist])
+      saveFilename[exist] <- unlist(lapply(saveFilename[exist], nextNumericName))
     }
     FBAll <- nchar(fnsAll) > 0
 
