@@ -330,9 +330,10 @@
   }
 
   # If it was a NULL, the cacheRepo stored it as "NULL" ... return it as NULL
-  if (is.character(output))
+  if (is.character(output)) {
     if (identical(as.character(output), "NULL"))
       output <- NULL
+  }
 
   return(output)
 }
