@@ -78,6 +78,11 @@
 #'     \code{file.size(file)} instead of the \code{digest::digest(file)}.
 #'     Less robust to changes, but faster. \emph{NOTE: this will only affect objects on disk}.
 #'   }
+#'   \item{\code{shapefileRead}}{
+#'     Default \code{NULL}. Used during \code{prepInputs} when reading a \code{.shp} file.
+#'     If \code{NULL}, it will use `sf::st_read` if `sf` package is available; otherwise,
+#'     it will use `raster::shapefile`
+#'   }
 #'   \item{\code{showSimilar}}{
 #'     Default \code{FALSE}. Passed to \code{Cache}.
 #'   }
@@ -177,6 +182,7 @@ reproducibleOptions <- function() {
     reproducible.overwrite = FALSE,
     reproducible.polygonShortcut = FALSE,
     reproducible.quick = FALSE,
+    reproducible.shapefileRead = "raster::shapefile", # TODO: change in next release
     reproducible.showSimilar = FALSE,
     reproducible.showSimilarDepth = 3,
     reproducible.tempPath = .reproducibleTempPath(),
@@ -185,7 +191,7 @@ reproducibleOptions <- function() {
     reproducible.useDBI = TRUE,
     reproducible.useGDAL = TRUE, #
     reproducible.useMemoise = FALSE, #memoise
-    reproducible.useNewDigestAlgorithm = 1,
+    reproducible.useNewDigestAlgorithm = 1, # TODO: change in next release
     reproducible.useragent = "https://github.com/PredictiveEcology/reproducible",
     reproducible.verbose = 1
   )
