@@ -688,12 +688,12 @@ test_that("test Cache argument inheritance to inner functions", {
   expect_true(sum(grepl(paste(.loadedCacheResultMsg, "outer call"), out)) == 1)
 
   # doubly nested
-  inner <- function(mean) {
+  inner <- function(mean, useCache = TRUE) {
     d <- 1
-    Cache(rnorm, n = 3, mean = mean)
+    Cache(rnorm, n = 3, mean = mean, useCache = useCache)
   }
-  outer <- function(n) {
-    Cache(inner, 0.1)
+  outer <- function(n, useCache = TRUE, ...) {
+    Cache(inner, 0.1, useCache = useCache, ...)
   }
   out <- capture_messages(Cache(outer, n = 2, cacheRepo = tmpdir))
   #expect_true(all(grepl("There is no similar item in the cacheRepo", out)))
@@ -1258,3 +1258,67 @@ test_that("test .object arg for list in Cache", {
   expect_false(identical(out2, out3))
 
 })
+
+test_that("quick arg in Cache as character", {
+  testInitOut <- testInit("raster", tmpFileExt = c("rds", "tif"))
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+
+  tf <- tmpfile[[1]]
+  tf2 <- tmpfile[[2]]
+
+  messes <- list()
+  quicks <- rep(list(FALSE, FALSE, "file", "file", TRUE, TRUE), 2)
+  rasRan <- c(rep(TRUE, 6), rep(FALSE, 6))
+  for (i in seq(quicks)) {
+    vals <- if (rasRan[i]) sample(1:100) else 1:100
+    ranRas <- raster(extent(0,10,0,10), vals = vals);
+    ranRas <- suppressWarningsSpecific(
+      falseWarnings = proj6Warn,
+      writeRaster(ranRas, filename = tf2, overwrite = TRUE))
+    a <- sample(1e7, 1);
+    saveRDS(a, file = tf);
+
+    # new copy
+    messes[[i]] <- capture_messages(Cache(saveRDS, ranRas, file = tf, cacheRepo = tmpCache,
+                                          quick = quicks[[i]]))
+
+  }
+  expect_true(length(messes[[6]]) > 0) # undesireable quick = FALSE -- even when raster has changed
+  expect_true(length(messes[[8]]) == 0) # undesireable quick = FALSE -- even when raster not changed, but file yes
+  # Desired -- 9 not cache, 10 cached
+  expect_true(length(messes[[9]]) == 0) # undesireable quick = FALSE -- even when raster not changed, but file yes
+  expect_true(length(messes[[10]]) > 0) # undesireable quick = FALSE -- even when raster not changed, but file yes
+  expect_true(sum(unlist(lapply(messes, function(x) length(x) > 0))) == 4L)
+
+})
+
+test_that("List of Rasters", {
+  testInitOut <- testInit("raster", tmpFileExt = c("tif", "tif"))
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+
+  listOfRas <- lapply(1:2, function(x) {
+    vals <- sample(1:100)
+    ranRas <- raster(extent(0,10,0,10), vals = vals);
+    ranRas <- suppressWarningsSpecific(
+      falseWarnings = proj6Warn,
+      writeRaster(ranRas, filename = tmpfile[[x]], overwrite = TRUE))
+  })
+
+  writeRasterList <- function(rasList) {
+    lapply(rasList, function(ras) {
+      filename <- paste0(Filenames(ras), rndstr(1, 6), ".tif")
+      ranRas <- suppressWarningsSpecific(
+        falseWarnings = proj6Warn,
+        writeRaster(ras, filename = filename, overwrite = TRUE))
+    }
+    )
+  }
+  a <- Cache(writeRasterList, listOfRas)
+  b <- Cache(writeRasterList, listOfRas)
+  expect_false(isTRUE(attr(b, ".Cache")$newCache))
+  expect_true(isTRUE(attr(a, ".Cache")$newCache))
+})
