@@ -3,13 +3,17 @@ test_that("all exported functions have examples", {
   omit <- which(fns == "cache") ## cache is deprecated, so omit it
 
   ## for debugging only:
-  tmpDir <- "~/tmp"
+  tmpDir <- if (grepl("VIC-", Sys.info()["nodename"]))  {
+    checkPath("~/tmp", create = TRUE)
+  } else {
+    checkPath(tempdir(), create = TRUE)
+  }
   tmpExFile <- file.path(tmpDir, "test-examples-out.txt")
-  if (!dir.exists(tmpDir)) dir.create(tmpDir, recursive = TRUE)
+
   if (grepl("VIC-", Sys.info()["nodename"]))  {
-     cat("#START##############\n", file = tmpExFile, append = FALSE)
-  #   cat(fns[-omit], sep = "\n", file = tmpExFile, append = TRUE)
-  #   cat("#END##############\n", file = tmpExFile, append = TRUE)
+    cat("#START##############\n", file = tmpExFile, append = FALSE)
+    # cat(fns[-omit], sep = "\n", file = tmpExFile, append = TRUE)
+    # cat("#END##############\n", file = tmpExFile, append = TRUE)
   }
 
   manDir <- if (dir.exists("../../man")) {
