@@ -6,7 +6,9 @@ test_that("prepInputs in a simple one double nested zip file, passing only desti
   }, add = TRUE)
 
   url <- "https://github.com/tati-micheletti/host/raw/master/data/rasterNested.zip"
-  testZip <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
+  noisyOutput <- capture.output(
+    testZip <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
+  )
   expect_true(exists("testZip"))
 })
 
@@ -18,9 +20,11 @@ test_that("prepInputs in a simple one double nested zip file, passing targetFile
   }, add = TRUE)
 
   url <- "https://github.com/tati-micheletti/host/raw/master/data/rasterNested.zip"
-  testZip2 <- reproducible::prepInputs(url = url,
-                             targetFile = "rasterTest.tif",
-                             destinationPath = tmpdir)
+  noisyOutput <- capture.output(
+    testZip2 <- reproducible::prepInputs(url = url,
+                                         targetFile = "rasterTest.tif",
+                                         destinationPath = tmpdir)
+  )
   expect_true(exists("testZip2"))
 })
 
@@ -32,7 +36,9 @@ test_that("prepInputs in a two files double nested zip file, passing only destin
   }, add = TRUE)
 
   url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesOutter.zip"
-  testZip3 <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
+  noisyOutput <- capture.output(
+    testZip3 <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
+  )
   expect_true(exists("testZip3"))
 })
 
@@ -44,9 +50,11 @@ test_that("prepInputs in a two files double nested zip file, passing targetFile"
   }, add = TRUE)
 
   url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesOutter.zip"
-  testZip4 <- reproducible::prepInputs(url = url,
-                                       targetFile = "rasterTest.tif",
-                                       destinationPath = tmpdir)
+  noisyOutput <- capture.output(
+    testZip4 <- reproducible::prepInputs(url = url,
+                                         targetFile = "rasterTest.tif",
+                                         destinationPath = tmpdir)
+  )
   expect_true(exists("testZip4"))
 })
 
@@ -55,40 +63,44 @@ test_that(
     "prepInputs in a two files double nested zip file, with the wanted file in",
     "the second layer, and a shapefile in the first, not specifying the targetFile"
   ), {
-  skip_on_cran()
-  testInitOut <-
-    testInit("raster", needGoogle = FALSE)
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+    skip_on_cran()
+    testInitOut <-
+      testInit("raster", needGoogle = FALSE)
+    on.exit({
+      testOnExit(testInitOut)
+    }, add = TRUE)
 
-  # Gets the first file it finds, the shapefile; warns the user about it
-  url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesMultiLevels.zip"
-  # The warning is about the .prj file missing, which is not relevant here -
-  #   Capture it and do nothing with it
-  warn <- capture_warnings({
-    testZip6 <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
+    # Gets the first file it finds, the shapefile; warns the user about it
+    url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesMultiLevels.zip"
+    # The warning is about the .prj file missing, which is not relevant here -
+    #   Capture it and do nothing with it
+    noisyOutput <- capture.output(
+      warn <- capture_warnings({
+        testZip6 <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
+      })
+    )
+    expect_true(exists("testZip6"))
+    expect_is(testZip6, shapefileClassDefault)
   })
-  expect_true(exists("testZip6"))
-  expect_is(testZip6, "SpatialPolygonsDataFrame")
-})
 
 test_that(
   paste0("prepInputs in a two files double nested zip file, with the wanted file in",
          "the second layer, and a shapefile in the first, specifying the targetFile"), {
-  skip_on_cran()
-  testInitOut <- testInit("raster", needGoogle = FALSE)
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+           skip_on_cran()
+           testInitOut <- testInit("raster", needGoogle = FALSE)
+           on.exit({
+             testOnExit(testInitOut)
+           }, add = TRUE)
 
-  url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesMultiLevels.zip"
-  testZip7 <- reproducible::prepInputs(url = url,
-                                       targetFile = "rasterTest.tif",
-                                       destinationPath = tmpdir)
-  expect_true(exists("testZip7"))
-  expect_is(testZip7, "RasterLayer")
-})
+           url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesMultiLevels.zip"
+           noisyOutput <- capture.output(
+             testZip7 <- reproducible::prepInputs(url = url,
+                                                  targetFile = "rasterTest.tif",
+                                                  destinationPath = tmpdir)
+           )
+           expect_true(exists("testZip7"))
+           expect_is(testZip7, "RasterLayer")
+         })
 
 test_that(
   paste("prepInputs in a two files double nested rar file,",
@@ -102,18 +114,23 @@ test_that(
 
           extractSystemCallPath <- .archiveExtractBinary()
           if (is.null(extractSystemCallPath)) {
-            warn <- capture_warnings({
-              expect_error({
-                testRar <- reproducible::prepInputs(
-                  url = "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar",
-                  destinationPath = tmpdir
-                )
+            noisyOutput <- capture.output(
+              warn <- capture_warnings({
+                expect_error({
+                  testRar <- reproducible::prepInputs(
+                    url = "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar",
+                    destinationPath = tmpdir
+                  )
+                })
               })
-            })
+            )
           } else {
-            testRar <- reproducible::prepInputs(
-              url = "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar",
-              destinationPath = tmpdir)
+
+            noisyOutput <- capture.output(
+              testRar <- reproducible::prepInputs(
+                url = "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar",
+                destinationPath = tmpdir)
+            )
             expect_true(exists("testRar"))
             expect_is(testRar, "RasterLayer")
           }
@@ -133,15 +150,18 @@ test_that(
       extractSystemCallPath <- .archiveExtractBinary()
       url <- "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar"
       if (is.null(extractSystemCallPath)) {
-        expect_error({
+        noisyOutput <- capture.output(
+          expect_error({
+            testRar2 <- reproducible::prepInputs(url = url,
+                                                 targetFile = "rasterTOtestRAR.tif",
+                                                 destinationPath = tmpdir)
+          }))
+      } else {
+        noisyOutput <- capture.output(
           testRar2 <- reproducible::prepInputs(url = url,
                                                targetFile = "rasterTOtestRAR.tif",
                                                destinationPath = tmpdir)
-        })
-      } else {
-        testRar2 <- reproducible::prepInputs(url = url,
-                                             targetFile = "rasterTOtestRAR.tif",
-                                             destinationPath = tmpdir)
+        )
         expect_true(exists("testRar2"))
         expect_is(testRar2, "RasterLayer")
       }
@@ -159,17 +179,20 @@ test_that(paste0("prepInputs in a two files double nested rar file, with the wan
                    extractSystemCallPath <- .archiveExtractBinary()
                    url <- "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar"
                    if (is.null(extractSystemCallPath)) {
-                     expect_error({
+                     noisyOutput <- capture.output(
+                       expect_error({
+                         testRar3 <- reproducible::prepInputs(url = url,
+                                                              archive = "nestedRarTxtFiles.rar",
+                                                              targetFile = "rasterTOtestRAR.tif",
+                                                              destinationPath = tmpdir)
+                       }))
+                   } else {
+                     noisyOutput <- capture.output(
                        testRar3 <- reproducible::prepInputs(url = url,
                                                             archive = "nestedRarTxtFiles.rar",
                                                             targetFile = "rasterTOtestRAR.tif",
                                                             destinationPath = tmpdir)
-                     })
-                   } else {
-                     testRar3 <- reproducible::prepInputs(url = url,
-                                                          archive = "nestedRarTxtFiles.rar",
-                                                          targetFile = "rasterTOtestRAR.tif",
-                                                          destinationPath = tmpdir)
+                     )
                      expect_true(exists("testRar3"))
                      expect_is(testRar3, "RasterLayer")
                    }
@@ -189,17 +212,21 @@ test_that("prepInputs works with nested rar file inside internal rar folder", {
   extractSystemCallPath <- .archiveExtractBinary()
   url <- "https://github.com/tati-micheletti/host/raw/master/data/testRasterNested.rar"
   if (is.null(extractSystemCallPath)) {
-    expect_error({
+    noisyOutput <- capture.output(
+      expect_error({
+        testRar4 <- reproducible::prepInputs(url = url,
+                                             targetFile = "rasterTest.tif",
+                                             destinationPath = tmpdir,
+                                             useCache = FALSE)
+      })
+    )
+  } else {
+    noisyOutput <- capture.output(
       testRar4 <- reproducible::prepInputs(url = url,
                                            targetFile = "rasterTest.tif",
                                            destinationPath = tmpdir,
                                            useCache = FALSE)
-    })
-  } else {
-    testRar4 <- reproducible::prepInputs(url = url,
-                                         targetFile = "rasterTest.tif",
-                                         destinationPath = tmpdir,
-                                         useCache = FALSE)
+    )
     expect_true(exists("testRar4"))
     expect_is(testRar4, "RasterLayer")
   }
